# chickenstats
A python library for scraping & analyzing sports statistics

<p align="center">
  <a href="https://chickenstats.com"><img src="https://raw.githubusercontent.com/chickenandstats/chickenstats/main/docs/assets/hero_white.png" alt="chickenstats"></a>
</p>

<p align="center">

<a href="https://github.com/chickenandstats/chickenstats/actions/workflows/tests.yml" target="_blank">
    <img src="https://github.com/chickenandstats/chickenstats/actions/workflows/tests.yml/badge.svg" alt="Tests">
</a>

<img alt="Codecov branch" src="https://img.shields.io/codecov/c/github/chickenandstats/chickenstats/main">

<a href="https://pypi.org/project/chickenstats" target="_blank">
    <img src="https://img.shields.io/pypi/pyversions/chickenstats.svg?color=%2334D058" alt="Supported Python versions">
</a>

<a href="https://pypi.org/project/chickenstats" target="_blank">
    <img src="https://img.shields.io/pypi/v/chickenstats?color=%2334D058&label=pypi%20package" alt="Package version">
</a>

<img alt="GitHub License" src="https://img.shields.io/github/license/chickenandstats/chickenstats?color=BrightGreen">

<a href="https://github.com/psf/black" target="_blank">
    <img src="https://img.shields.io/badge/code%20style-black-000000.svg" alt="Code style: black">
</a>

</p>

---

**Documentation**: <a href="https://chickenstats.com" target="_blank">https://chickenstats.com</a>

**Source Code**: <a href="https://github.com/chickenandstats/chickenstats" target="_blank">https://github.com/chickenandstats/chickenstats</a>

---

 
